- make stand alone docking stages (currently have protein predictors)
- rename docking to varidock in import
- standardize test directory
- data provenance & return typings
- submitter paradigm for large-scale single step vs rapid multi-step

-        ## this should prob be an input to the stage, but for now we'll just copy the templates
 in  vmd equil prepp
 alaso need to change it to remove UNK residues 